==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/en/dashboards.inc.php <==
<?php
/**
 * English language strings for Dashboards
 *
 * @package modx
 * @subpackage lexicon
 * @language en
 */
$_lang['dashboard'] = 'Dashboard';
$_lang['dashboard_add'] = 'Add Dashboard';
$_lang['dashboard_create'] = 'Create Dashboard';
$_lang['dashboard_desc_name'] = 'The name of the Dashboard.';
$_lang['dashboard_desc_description'] = 'A short description of the Dashboard.';
$_lang['dashboard_desc_hide_trees'] = 'Checking this will hide the left-hand trees when this Dashboard is rendered on the welcome page.';
$_lang['dashboard_hide_trees'] = 'Hide Left-Hand Trees';
$_lang['dashboard_duplicate'] = 'Duplicate Dashboard';
$_lang['dashboard_remove'] = 'Delete Dashboard';
$_lang['dashboard_remove_confirm'] = 'Are you sure you want to remove this Dashboard?';
$_lang['dashboard_update'] = 'Update Dashboard';
$_lang['dashboard_err_ae_name'] = 'A dashboard with the name "[[+name]]" already exists! Please try another name.';
$_lang['dashboard_err_duplicate'] = 'An error occurred while trying to duplicate the dashboard.';
$_lang['dashboard_err_nf'] = 'Dashboard not found.';
$_lang['dashboard_err_ns'] = 'Dashboard not specified.';
$_lang['dashboard_err_ns_name'] = 'Please specify a name for the widget.';
$_lang['dashboard_err_remove'] = 'An error occurred while trying to remove the Dashboard.';
$_lang['dashboard_err_remove_default'] = 'You cannot remove the default Dashboard!';
$_lang['dashboard_err_save'] = 'An error occurred while trying to save the Dashboard.';
$_lang['dashboard_usergroup_add'] = 'Assign Dashboard to User Group';
$_lang['dashboard_usergroup_remove'] = 'Remove Dashboard from User Group';
$_lang['dashboard_usergroup_remove_confirm'] = 'Are you sure you want to revert this User Group to using the default Dashboard?';
$_lang['dashboard_usergroups.intro_msg'] = 'Here is a list of all the User Groups using this Dashboard.';
$_lang['dashboard_widget_err_placed'] = 'This widget is already placed in this Dashboard!';
$_lang['dashboard_widgets.intro_msg'] = 'Here you can add, manage, and remove Widgets from this Dashboard. You can also drag and drop the rows in the grid to rearrange them.';
$_lang['dashboards'] = 'Dashboards';
$_lang['dashboards.intro_msg'] = 'Here you can manage all the available Dashboards for this MODX manager.';
$_lang['rank'] = 'Rank';
$_lang['user_group_filter'] = 'By User Group';
$_lang['widget'] = 'Widget';
$_lang['widget_content'] = 'Widget Content';
$_lang['widget_create'] = 'Create New Widget';
$_lang['widget_err_ae_name'] = 'A widget with the name "[[+name]]" already exists! Please try another name.';
$_lang['widget_err_nf'] = 'Widget not found!';
$_lang['widget_err_ns'] = 'Widget not specified!';
$_lang['widget_err_ns_name'] = 'Please specify a name for the widget.';
$_lang['widget_err_remove'] = 'An error occurred while trying to remove the Widget.';
$_lang['widget_err_save'] = 'An error occurred while trying to save the Widget.';
$_lang['widget_file'] = 'File';
$_lang['widget_dashboards.intro_msg'] = 'Below is a list of all the Dashboards that this Widget has been placed on.';
$_lang['widget_dashboard_remove'] = 'Remove Widget From Dashboard';
$_lang['widget_description_desc'] = 'A description, or Lexicon Entry key, of the Widget and what it does.';
$_lang['widget_html'] = 'HTML';
$_lang['widget_lexicon_desc'] = 'The Lexicon Topic to load with this Widget. Useful for providing translations for the name and description, as well as any text in the widget.';
$_lang['widget_name_desc'] = 'The name, or Lexicon Entry key, of the Widget.';
$_lang['widget_new'] = 'New Widget';
$_lang['widget_remove'] = 'Delete Widget';
$_lang['widget_remove_confirm'] = 'Are you sure you want to remove this Dashboard Widget? This is permanent, and will remove the Widget from all Dashboards.';
$_lang['widget_remove_multiple'] = 'Delete Multiple Widgets';
$_lang['widget_remove_multiple_confirm'] = 'Are you sure you want to remove these Dashboard Widgets? This is permanent, and will remove the Widgets from all their assigned Dashboards.';
$_lang['widget_namespace'] = 'Namespace';
$_lang['widget_namespace_desc'] = 'The Namespace that this widget will be loaded into. Useful for custom paths.';
$_lang['widget_php'] = 'Inline PHP Widget';
$_lang['widget_place'] = 'Place Widget';
$_lang['widget_size'] = 'Size';
$_lang['widget_size_desc'] = 'The size of the widget. Can either be a half-screen wide ("Half"), the width of the screen ("Full"), or a full screen width and two rows ("Double").';
$_lang['widget_size_double'] = 'Double';
$_lang['widget_size_full'] = 'Full';
$_lang['widget_size_half'] = 'Half';
$_lang['widget_snippet'] = 'Snippet';
$_lang['widget_type'] = 'Widget Type';
$_lang['widget_type_desc'] = 'The type of widget this is. "Snippet" widgets are MODX Snippets that are run and return their output. "HTML" widgets are just straight HTML. "File" widgets are loaded directly from files, which can either return their output or the name of the modDashboardWidgetClass-extended class to load. "Inline PHP" Widgets are widgets that are straight PHP in the widget content, similar to a Snippet.';
$_lang['widget_unplace'] = 'Remove Widget from Dashboard';
$_lang['widget_update'] = 'Update Widget';
$_lang['widgets'] = 'Widgets';
$_lang['widgets.intro_msg'] = 'Below is a list of all the installed Dashboard Widgets you have.';

$_lang['w_configcheck'] = 'Configuration Check';
$_lang['w_configcheck_desc'] = 'Displays a configuration check that ensures your MODX install is secure.';
$_lang['w_newsfeed'] = 'MODX News Feed';
$_lang['w_newsfeed_desc'] = 'Displays the MODX News Feed';
$_lang['w_recentlyeditedresources'] = 'Recently Edited Resources';
$_lang['w_recentlyeditedresources_desc'] = 'Shows a list of the most recently edited resources by the user.';
$_lang['w_securityfeed'] = 'MODX Security Feed';
$_lang['w_securityfeed_desc'] = 'Displays the MODX Security Feed';
$_lang['w_whosonline'] = 'Who\'s Online';
$_lang['w_whosonline_desc'] = 'Shows a list of online users.';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/dashboards.inc.php <==
<?php
/**
 * English language strings for Dashboards
 *
 * @package modx
 * @subpackage lexicon
 * @language en
 */
$_lang['dashboard'] = 'Dashboard';
$_lang['dashboard_add'] = 'Add Dashboard';
$_lang['dashboard_create'] = 'Create Dashboard';
$_lang['dashboard_desc_name'] = 'The name of the Dashboard.';
$_lang['dashboard_desc_description'] = 'A short description of the Dashboard.';
$_lang['dashboard_desc_hide_trees'] = 'Checking this will hide the left-hand trees when this Dashboard is rendered on the welcome page.';
$_lang['dashboard_hide_trees'] = 'Hide Left-Hand Trees';
$_lang['dashboard_duplicate'] = 'Duplicate Dashboard';
$_lang['dashboard_remove'] = 'Delete Dashboard';
$_lang['dashboard_remove_confirm'] = 'Are you sure you want to remove this Dashboard?';
$_lang['dashboard_remove_multiple'] = 'Remove Dashboards';
$_lang['dashboard_remove_multiple_confirm'] = 'Are you sure you want to remove the selected Dashboards?';
$_lang['dashboard_update'] = 'Update Dashboard';
$_lang['dashboard_err_ae_name'] = 'A dashboard with the name "[[+name]]" already exists! Please try another name.';
$_lang['dashboard_err_duplicate'] = 'An error occurred while trying to duplicate the dashboard.';
$_lang['dashboard_err_nf'] = 'Dashboard not found.';
$_lang['dashboard_err_ns'] = 'Dashboard not specified.';
$_lang['dashboard_err_ns_name'] = 'Please specify a name for the widget.';
$_lang['dashboard_err_remove'] = 'An error occurred while trying to remove the Dashboard.';
$_lang['dashboard_err_remove_default'] = 'You cannot remove the default Dashboard!';
$_lang['dashboard_err_save'] = 'An error occurred while trying to save the Dashboard.';
$_lang['dashboard_usergroup_add'] = 'Assign Dashboard to User Group';
$_lang['dashboard_usergroup_remove'] = 'Remove Dashboard from User Group';
$_lang['dashboard_usergroup_remove_confirm'] = 'Are you sure you want to revert this User Group to using the default Dashboard?';
$_lang['dashboard_usergroups.intro_msg'] = 'Here is a list of all the User Groups using this Dashboard.';
$_lang['dashboard_widget_err_placed'] = 'This widget is already placed in this Dashboard!';
$_lang['dashboard_widgets.intro_msg'] = 'Here you can add, manage, and remove Widgets from this Dashboard. You can also drag and drop the rows in the grid to rearrange them.';
$_lang['dashboards'] = 'Dashboards';
$_lang['dashboards.intro_msg'] = 'Here you can manage all the available Dashboards for this MODX manager.';
$_lang['rank'] = 'Rank';
$_lang['user_group_filter'] = 'By User Group';
$_lang['widget'] = 'Widget';
$_lang['widget_content'] = 'Widget Content';
$_lang['widget_create'] = 'Create New Widget';
$_lang['widget_err_ae_name'] = 'A widget with the name "[[+name]]" already exists! Please try another name.';
$_lang['widget_err_nf'] = 'Widget not found!';
$_lang['widget_err_ns'] = 'Widget not specified!';
$_lang['widget_err_ns_name'] = 'Please specify a name for the widget.';
$_lang['widget_err_remove'] = 'An error occurred while trying to remove the Widget.';
$_lang['widget_err_save'] = 'An error occurred while trying to save the Widget.';
$_lang['widget_file'] = 'File';
$_lang['widget_dashboards.intro_msg'] = 'Below is a list of all the Dashboards that this Widget has been placed on.';
$_lang['widget_dashboard_remove'] = 'Remove Widget From Dashboard';
$_lang['widget_description_desc'] = 'A description, or Lexicon Entry key, of the Widget and what it does.';
$_lang['widget_html'] = 'HTML';
$_lang['widget_lexicon_desc'] = 'The Lexicon Topic to load with this Widget. Useful for providing translations for the name and description, as well as any text in the widget.';
$_lang['widget_name_desc'] = 'The name, or Lexicon Entry key, of the Widget.';
$_lang['widget_new'] = 'New Widget';
$_lang['widget_remove'] = 'Delete Widget';
$_lang['widget_remove_confirm'] = 'Are you sure you want to remove this Dashboard Widget? This is permanent, and will remove the Widget from all Dashboards.';
$_lang['widget_remove_multiple'] = 'Delete Multiple Widgets';
$_lang['widget_remove_multiple_confirm'] = 'Are you sure you want to remove these Dashboard Widgets? This is permanent, and will remove the Widgets from all their assigned Dashboards.';
$_lang['widget_namespace'] = 'Namespace';
$_lang['widget_namespace_desc'] = 'The Namespace that this widget will be loaded into. Useful for custom paths.';
$_lang['widget_php'] = 'Inline PHP Widget';
$_lang['widget_place'] = 'Place Widget';
$_lang['widget_size'] = 'Size';
$_lang['widget_size_desc'] = 'The size of the widget. Can either be a half-screen wide ("Half"), the width of the screen ("Full"), or a full screen width and two rows ("Double").';
$_lang['widget_size_double'] = 'Double';
$_lang['widget_size_full'] = 'Full';
$_lang['widget_size_half'] = 'Half';
$_lang['widget_snippet'] = 'Snippet';
$_lang['widget_type'] = 'Widget Type';
$_lang['widget_type_desc'] = 'The type of widget this is. "Snippet" widgets are MODX Snippets that are run and return their output. "HTML" widgets are just straight HTML. "File" widgets are loaded directly from files, which can either return their output or the name of the modDashboardWidgetClass-extended class to load. "Inline PHP" Widgets are widgets that are straight PHP in the widget content, similar to a Snippet.';
$_lang['widget_unplace'] = 'Remove Widget from Dashboard';
$_lang['widget_update'] = 'Update Widget';
$_lang['widgets'] = 'Widgets';
$_lang['widgets.intro_msg'] = 'Below is a list of all the installed Dashboard Widgets you have.';

$_lang['w_configcheck'] = 'Configuration Check';
$_lang['w_configcheck_desc'] = 'Displays a configuration check that ensures your MODX install is secure.';
$_lang['w_newsfeed'] = 'MODX News Feed';
$_lang['w_newsfeed_desc'] = 'Displays the MODX News Feed';
$_lang['w_recentlyeditedresources'] = 'Recently Edited Resources';
$_lang['w_recentlyeditedresources_desc'] = 'Shows a list of the most recently edited resources by the user.';
$_lang['w_securityfeed'] = 'MODX Security Feed';
$_lang['w_securityfeed_desc'] = 'Displays the MODX Security Feed';
$_lang['w_whosonline'] = 'Who\'s Online';
$_lang['w_whosonline_desc'] = 'Shows a list of online users.';
